==> db4o-5.0-mono.tar.gz: db4o-5.0/src/test/src/com/db4o/test/types/RTest.cs <==
/* Copyright (C) 2004 - 2005  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
namespace com.db4o.test.types {

   public abstract class RTest: RTestable {
      
      public RTest() : base() {
      }
      
      public Object newInstance() {
         try {
            {
               return j4o.lang.Class.getClassForObject(this).newInstance();
            }
         }  catch (Exception e) {
            {
               return null;
            }
         }
      }
      
      public Object set(Object obj, int ver) {
         ((RTest)obj).set(ver);
         return obj;
      }
      
      public abstract void set(int ver);
      
      public void compare(ObjectContainer con, Object obj, int ver) {
         TestUtil.compare(con, set(newInstance(), ver), obj, "", null);
      }
      
      public virtual bool jdk2() {
         return false;
      }
      
      public bool ver3() {
         return false;
      }
   }
}

==> db4o-5.5-mono.tar.gz: db4o-5.5/src/test/src/com/db4o/test/types/RTest.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
using System;
using j4o.lang;
using com.db4o;
namespace com.db4o.test.types {

   public abstract class RTest: RTestable {
      
      public RTest() : base() {
      }
      
      public Object NewInstance() {
         try {
            {
               return j4o.lang.Class.GetClassForObject(this).NewInstance();
            }
         }  catch (Exception e) {
            {
               return null;
            }
         }
      }
      
      public Object Set(Object obj, int ver) {
         ((RTest)obj).Set(ver);
         return obj;
      }
      
      public abstract void Set(int ver);
      
      public void Compare(ObjectContainer con, Object obj, int ver) {
         TestUtil.Compare(con, Set(NewInstance(), ver), obj, "", null);
      }
      
      public virtual bool Jdk2() {
         return false;
      }
      
      public bool Ver3() {
         return false;
      }
   }
}
